//BEGIN COPYRIGHT */
//*************************************************************************
//
//  Licensed Materials - Property of IBM
//  5697-FM3 5655-A96
//  (C) Copyright IBM Corp. 1999
//  US Government Users Restricted Rights - Use, duplication or
//  disclosure restricted by GSA ADP Schedule Contract
//  with IBM Corp.
//
//************************************************************************/
//END COPYRIGHT */
//BEGIN DISCLAIMER */
//*************************************************************************
//  DISCLAIMER
//  ----------
//  This material contains programming source code for your consideration.
//  These examples have not been thoroughly tested under all conditions.
//  IBM, therefore, cannot guarantee or imply reliability, serviceability,
//  or function of these programs.
//  ALL PROGRAMS CONTAINED HEREIN ARE PROVIDED TO YOU "AS IS", WITHOUT ANY
//  WARRANTIES (EXPRESS OR IMPLIED) OR SUPPORT WHATSOEVER, INCLUDING BUT
//  NOT LIMITED TO ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
//  FOR A PARTICULAR PURPOSE.
//************************************************************************/
//END DISCLAIMER */
//*************************************************************************
//
//  This application is an example of an activity implementation written
//  in Java.
//
//  It has the following prerequisites:
//  - Java Runtime Environment (JRE)
//    V1.1.x, where x >=6, has to be installed and correctly configured on
//    the machine where it is supposed to be run.
//  - The MQSeries workflow components Java CORBA Agent and Runtime Client
//    have to be installed on the machine where it is supposed to be run.
//
//  In order to run this sample you have to
//  - adapt the file AddPerson.fdl:
//    replace all occurences of @MQWFInstallDir@ with your MQSeries
//    Workflow installation directory. You may also have to adapt the
//    version of the MQWF Java CORBA Agent codelevel,
//    e.g. change ...\bin\java3210 to the version which matches your
//    installation.
//  - import AddPerson.fdl into the runtime database.
//    E.g. fmcibie -uADMIN -ppassword -oti AddPerson.fdl
//  - create and start an instance of the processtemplate
//    'AddPerson'
//
//************************************************************************/
import com.ibm.workflow.api.*;
import com.ibm.workflow.api.ServicePackage.*;

public class GoCheckUser
{
  public static void main( String[] argv )
  {
    try
    {
      Agent agent = new Agent( );

      agent.setLocator( Agent.LOC_LOCATOR );
      agent.setName( "LOCAL" );

      ExecutionAgent pea = agent.getExecutionAgent( );
      
      if ( pea != null )
      {
        // get the input- and output container
        ReadOnlyContainer  input  = pea.inContainer( );
        ReadWriteContainer output = pea.outContainer( );

        output.setLong("_RC", 2);

        // copy the data members from the input- to the output container
        
        System.out.println( "Copy Containers:" );

        ContainerElement FirstName = input.getElement("UserFirstName");
        String FirstNameString = FirstName.getString();
        output.setString( "AddUser.UserFirstName", FirstNameString );
        System.out.println( "Contain Value:" + FirstNameString );
        
        ContainerElement SecondName = input.getElement("UserSecondName");
        String SecondNameString = SecondName.getString();
        output.setString( "AddUser.UserSecondName", SecondNameString );
        System.out.println( "Contain Value:" + SecondNameString );

        ContainerElement UserID = input.getElement("UserID");
        String UserIDString = UserID.getString();
        output.setString( "AddUser.UserID", UserIDString );
        System.out.println( "Contain Value:" + UserIDString );

        System.out.println( "Starting Logon:" );

        ExecutionService service = agent.locate("", "");
                
        output.setLong("_RC", 3);          //user OK
        output.setString( "Error", "User Found" );

        try
        {
          service.logon2(UserIDString, "password", SessionMode.PRESENT,
                       AbsenceIndicator.LEAVE );
          service.logoff();
        }
        catch (FmcException e) 
        {
          if (e.rc == 10) {                 
            output.setLong("_RC", 1);       //user not found
            output.setString( "Error", e.messageText );
            System.out.println( "RC:1" );
          }
          else
          {
            output.setLong("_RC", 2);      //user error
            output.setString( "Error", e.messageText );
            System.out.println( "RC:2" );
          }
        }
        
        System.out.println( "Complete:" );

        // return the output container to the PEA
        pea.setOutContainer( output );
      }
    }
    catch( FmcException xcpt )
    {
        System.out.println( "Error in MQSeries Workflow call:" );
     
        // Catch and report details about the FmcException
        System.out.println("FmcException occured");
        System.out.println("  RC         : " + xcpt.rc);
        System.out.println("  Origin     : " + xcpt.origin);
        System.out.println("  MessageText: " + xcpt.messageText);
        System.out.println("  Exception  : " + xcpt.getMessage());
        System.out.println("  Parameters : ");
  
        System.out.println("  StackTrace : ");
        xcpt.printStackTrace();
        
    }
    catch( Throwable xcpt )
    {
      System.out.println( "Internal error:" );
      xcpt.printStackTrace( );
    }
    finally
    {
      try
      {
        //  This code will pause the program so that you can see what has happend and is about to happen. 
        //  Left this for your own debugging purpose. You can remove it you wish.
        System.out.println( );
        System.out.println( "Press ENTER to end the program." );
        System.in.read( );
      }
      catch( Exception xcpt )
      { }
    }
  }
}
